% Compute transformation matrix describing local material directions.
% XYZ = location at which the material directions are needed
% ts = tangent vectors to parametric coordinates in columns
%
% The basic assumption here is that the material is isotropic, and
% therefore the choice of the material directions does not really matter as
% long as they correspond to the dimensionality of the element.
% 
% This function assumes that it is being called for
% and ntan-dimensional manifold element, which is embedded in a
% sdim-dimensional Euclidean space. If ntan == sdim,
% the material directions matrix is the identity; otherwise the local
% material directions are aligned with the linear subspace defined by the
% tangent vectors.
% 
function Rm = geniso_Rm(XYZ,ts)
    [sdim, ntan] = size(tangents);
    if sdim==ntan
        Rm=eye(sdim);
    else
        switch ntan
            case 1
                e1=tangents(:,1)/norm(tangents(:,1));
                Rm = [e1];
            case 2
                normal =skewmat(tangents(:,1))*tangents(:,2);
                e1=tangents(:,1)/norm(tangents(:,1));
                e2=skewmat(normal)*tangents(:,2);
                e2=e2/norm(e2);
                Rm = [e1,e2];
            otherwise
                error('Got an incorrect size of tangents');
        end
    end
end